-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-- Copyright 2016, Knowledge Resources GmbH
-- http://www.knowres.ch
--
-- FILE:        krc3701_usb_hub_reset.vhd
-- MODULE:      krc3701_usb_hub_reset
-- TITLE:       KRC3701 USB Hub Reset 
-------------------------------------------------------------------------------
-- DESCRIPTION: This is a lightweight module, which handles the USB Hub reset 
--              for the KRC3701 evaluation carrier.
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.NUMERIC_STD.ALL;

library UNISIM;
use UNISIM.VComponents.all;

entity krc3701_usb_hub_reset is
	Generic (
	NBITS : integer := 8;
	CNT_MAX : integer := 255
	);
	Port (
	clk : in std_logic;
	USB_HUB_RESET : out std_logic
	);
end krc3701_usb_hub_reset;

architecture Behavioral of krc3701_usb_hub_reset is
	
signal counter : unsigned(NBITS - 1 downto 0) := to_unsigned(CNT_MAX, NBITS);
	
begin
	process(clk)
	begin
		if rising_edge(clk) then
			if counter = to_unsigned(0,NBITS) then
			   USB_HUB_RESET <= '0';
			else
				counter <= counter - to_unsigned(1,NBITS);
				USB_HUB_RESET <= '1';
			end if;
		end if;
	end process;
	
	
end Behavioral;
